from .base import *  # noqa: F403
from .eegnet import EEGNet
from .shallownet import ShallowNet
from .convca import ConvCA
